pub struct SigningKeyIdentity { /* private fields */ }Expand description
Public identity of one signing key within one role.
Implementations
Sourceimpl SigningKeyIdentity
impl SigningKeyIdentity
Sourcepub fn for_public_key<R: SigningRole>(
public_key: Vec<u8>,
) -> Result<Self, SigningIdentityError>
pub fn for_public_key<R: SigningRole>( public_key: Vec<u8>, ) -> Result<Self, SigningIdentityError>
Derives the canonical identity for a trusted role public key.
Errors
Refuses a value that is not an encoded ed25519 public key.
Sourcepub fn checked<R: SigningRole>(
issuer: impl Into<String>,
claimed_key_id: impl Into<String>,
public_key: Vec<u8>,
) -> Result<Self, SigningIdentityError>
pub fn checked<R: SigningRole>( issuer: impl Into<String>, claimed_key_id: impl Into<String>, public_key: Vec<u8>, ) -> Result<Self, SigningIdentityError>
Reconstructs a public identity read from trusted custody metadata.
Errors
Refuses an issuer mismatch, malformed key, or key id not derived from the exact issuer and public key.
Sourcepub fn public_key(&self) -> &[u8] ⓘ
pub fn public_key(&self) -> &[u8] ⓘ
Encoded ed25519 public key.